@@ -357,13 +357,13 @@ class Process( PipeComponent ):
             if self.stdout:
                 # but stdout was captured, so we need to consume it to prevent deadlocks
                 self.iterables.append(
-                    reader( self.stdout )
+                    self.iter_read()
                 )
         if not self.stderr_needed:
             # nothing has been hooked to stderr
             if self.stderr:
                 self.iterables.append(
-                    reader( self.stderr )
+                    self.iter_write( self.stderr )
                 )
         if not self.stdin_needed:
             # nothing is being sent in, so input is finished...
@@ -480,6 +480,14 @@ def caller( iterable, target ):
             target( item )
         yield item
 
+#def pipeline( *commands ):
+#    pipe = []
+#    previous_stdout = subprocess.PIPE
+#    for command in commands:
+#        pipe.append( subprocess.Popen( command, stdin=previous_stdout, stdout=subprocess.PIPE ))
+#        previous_stdout = pipe[-1].stdout 
+#    return pipe
+
 def writeiter( iterator, fh ):
     """Write content from iterator to fh
     
